@@ -18,10 +18,10 @@
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  * Lesser General Public License for more details.
  *
- * You should have received a copy of the GNU Lesser General Public
- * License along with this library; if not, write to the 
- * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA  02111-1307, USA.
+ * You should have received a copy of the GNU Lesser General Public License
+ * along with this program; if not, write to the Free Software
+ * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301
+ * USA
  */
 
 
@@ -39,6 +39,7 @@ This class is the base document class.
 */
 class Document: public Object
 {
+friend class gcu::Object;
 public:
 /*!
 The default constructor. Creates an empty document.
@@ -51,15 +52,6 @@ The destructor of Document.
 
 public:
 
-/*!
-@param id: the original id
-
-When pasting, objects added to the document might have the same Id as objects already existing. In such cases, the document
-maintains a table to update links using Ids as identifiers. GetId adds a new entry in
-the table and returns the translated id
-*/
-	gchar* GetNewId (gchar* id);
-
 /*!
 @param id: the original id to tranlate
 
@@ -84,6 +76,19 @@ to avoid errors on the next paste event.
 */
 	void EmptyTranslationTable() {m_TranslationTable.clear();}
 
+private:
+
+/*!
+@param id: the original id
+@param Cache: 
+
+When pasting, objects added to the document might have the same Id as objects already existing. In such cases, the document
+maintains a table to update links using Ids as identifiers. If Chache is set to true GetId adds a new entry in
+the table.
+GetNewId returns the translated id
+*/
+	gchar* GetNewId (gchar* id, bool Cache = true);
+
 private:
 	map <string, string> m_TranslationTable;//used when Ids translations are necessary (on pasting...)
 };
